==> grs-1.2.tar.gz: grs-1.2/grs/buttonbox.h <==
/* $Id: buttonbox.h 53 2004-01-12 19:17:04Z takekawa $
 * Copyright (C) 2003 Takashi Takekawa
 * This file is part of the Grs Library
 *
 * This library is free software; You may redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have recieved a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundtion, Inc., 59 Temple Place, Suite 330, Bostom, MA
 * 02111-1307 USA.
 */

#ifndef GRS_BUTTONBOX_H
#define GRS_BUTTONBOX_H

#include <gtkmm/buttonbox.h>
#include <gtkmm/window.h>
#include <boost/function.hpp>
#include <grs/property.h>

namespace Grs {

class ButtonBox : public Gtk::VButtonBox
{
public:
    ButtonBox();

    virtual ~ButtonBox();

    void add_window(Gtk::Window& window);

    void add_func(const char* name, const boost::function<void()>& func);

    void add_thread(const char* name, const boost::function<bool()>& func);

    void add_toggle(const char* name, Property<bool>& flag);
    void add_toggle(const char* name,
            const boost::function<void()>& on,
            const boost::function<void()>& off);
    void add_toggle(const char* name, const boost::function<void(bool)>& func);

    void add_file_selection(const char* name,
            const boost::function<bool(const char*)>& function);
};

}

#endif

==> grs-1.3.tar.gz: grs-1.3/grs/buttonbox.h <==
/* $Id: buttonbox.h 53 2004-01-12 19:17:04Z takekawa $
 * Copyright (C) 2003 Takashi Takekawa
 * This file is part of the Grs Library
 *
 * This library is free software; You may redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have recieved a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundtion, Inc., 59 Temple Place, Suite 330, Bostom, MA
 * 02111-1307 USA.
 */

#ifndef GRS_BUTTONBOX_H
#define GRS_BUTTONBOX_H

#include <gtkmm/buttonbox.h>
#include <gtkmm/window.h>
#include <grs/property.h>

namespace Grs {

class ButtonBox : public Gtk::VButtonBox
{
public:
    ButtonBox();

    virtual ~ButtonBox();

    void add_window(Gtk::Window& window);

    void add_func(const char* name, const sigc::slot<void>& func);

    void add_thread(const char* name, const sigc::slot<bool>& func);

    void add_toggle(const char* name, Property<bool>& flag);
    void add_toggle(const char* name,
            const sigc::slot<void>& on, const sigc::slot<void>& off);
    void add_toggle(const char* name, const sigc::slot<void, bool>& func);

    void add_file_selection(const char* name,
            const sigc::slot<bool, const char*>& function);
};

}

#endif
